package com.fluentadflowreactnativesdk

import android.content.Context
import android.graphics.Color
import android.util.Log
import android.widget.FrameLayout
import android.app.Activity
import android.view.View
import android.os.Bundle
import android.view.ViewGroup
import android.widget.Button
import android.widget.Toast
import com.facebook.react.bridge.ReactApplicationContext
import com.facebook.react.bridge.ReactContext
import com.facebook.react.bridge.ReadableMap
import com.facebook.react.modules.core.DeviceEventManagerModule
import com.facebook.react.uimanager.ThemedReactContext
import com.fluent.adflowsdk.adflow.FluentAdflowStaticWrapper
import com.fluent.adflowsdk.adflow.IAdflowListener
import com.fluent.adflowsdk.adflow.IAdflowWidget


class FluentAdFlowWidgetView(context: ThemedReactContext) : FrameLayout(context) {
  private var reactContext: ThemedReactContext?
  init {
    this.reactContext = context
  }

  public fun launchWebView(params: ReadableMap) {
    val paramsMap = convertReadableMapToHashMap(params);
    val parentView = this;
    val adflowWidget: IAdflowWidget = FluentAdflowStaticWrapper.getInstance(reactContext);
    val sampleAdComponent: View = adflowWidget
      //optional listerner
      .setAdFlowListener(object : IAdflowListener {
        override fun onViewDismiss() {
          Log.d("tag", "close event")
          if (parentView.context != null) {
            parentView.reactContext
              ?.getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter::class.java)
              ?.emit("onAdFlowContainerClosed", null)
          }
        }
        override fun onViewLoaded() {
          Log.d("tag", "load event")
          if (parentView.context != null) {
            parentView.reactContext
              ?.getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter::class.java)
              ?.emit("onAdFlowContainerShow", null)
          }
        }
        override fun onContentHeightChanged(height: String ) {
          Log.d("tag", "height changed event")
          if (parentView.context != null) {
            parentView.reactContext
              ?.getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter::class.java)
                ?.emit("onAdFlowContainerHeightChanged", height)
          }
        }
      }).setParams(paramsMap);
    adflowWidget.show();
    addView(sampleAdComponent)
  }
  fun convertReadableMapToHashMap(readableMap: ReadableMap): HashMap<String, String> {
    val hashMap = HashMap<String, String>()
    val iterator = readableMap.keySetIterator()

    while (iterator.hasNextKey()) {
      val key = iterator.nextKey()
      val value = readableMap.getString(key)
      if (value != null) {
        hashMap[key] = value
      }
    }

    return hashMap
  }
  public fun setSdkWrapperName(name: String){
    FluentAdflowStaticWrapper.getInstance(reactContext).setSdkWrapperName(name);
  }
  public fun setSdkWrapperVersion(version: String){
    FluentAdflowStaticWrapper.getInstance(reactContext).setSdkWrapperVersion(version);
  }

}
